@@ -43,6 +43,10 @@ class IInterventionTabProxy(Interface):
     """An interface for getting the displayable value of a message or goal."""
 
 
+class IStudentSchoolYearsProxy(Interface):
+    """A marker interface for the student schoolyear proxy."""
+
+
 class IStudentSchoolYearProxy(Interface):
     """A marker interface for the student schoolyear proxy."""
 
@@ -165,7 +169,8 @@ class IInterventionGoal(IContained):
 
     goal_met = GoalMetField(
         title=u"Goal met",
-        required=False
+        required=False,
+        default=False,
         )
 
     follow_up_notes = Text(
